@@ -8,8 +8,7 @@ sub output_file { return 't/apache_test_run.pl'; }
 
 sub template { return <<ENDM; }
 use Apache::SWIT::Test::Apache;
-Apache::SWIT::Test::Apache->swit_run('../../blib/conf/httpd.conf'
-		, '../../blib/conf/httpd.conf');
+Apache::SWIT::Test::Apache->swit_run;
 ENDM
 
 1;
